@@ -1,7 +1,11 @@
-/* prim.h -- definitions for es primitives ($Revision: 1.6 $) */
+/* prim.h -- definitions for es primitives ($Revision: 1.7 $) */
 
 #define	PRIM(name)	static List *CONCAT(prim_,name)(List *list, int evalflags)
-#define	X(name)		(primdict = dictput(primdict, STRING(name), CONCAT(prim_,name)))
+#define	X(name)		(primdict = dictput( \
+				primdict, \
+				STRING(name), \
+				(void *) CONCAT(prim_,name) \
+			))
 
 extern Dict *initprims_controlflow(Dict *primdict);	/* prim-ctl.c */
 extern Dict *initprims_io(Dict *primdict);		/* prim-io.c */
